@@ -5,7 +5,7 @@
 # include "config.h"
 #endif
 
-#include <inttypes.h>
+#include "nettle-types.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -17,10 +17,14 @@
 
 #if WITH_PUBLIC_KEY
 # include "rsa.h"
+# include "dsa.h"
 #endif
 
 #include "nettle-meta.h"
 
+void *
+xalloc(size_t size);
+
 /* Decodes a NUL-terminated hex string. */
 
 unsigned
@@ -34,7 +38,7 @@ const uint8_t *
 decode_hex_dup(const char *hex);
 
 void
-print_hex(unsigned length, uint8_t *data);
+print_hex(unsigned length, const uint8_t *data);
 
 /* The main program */
 int
@@ -59,6 +63,23 @@ test_cipher_cbc(const struct nettle_cipher *cipher,
 		const uint8_t *ciphertext,
 		const uint8_t *iv);
 
+void
+test_cipher_ctr(const struct nettle_cipher *cipher,
+		unsigned key_length,
+		const uint8_t *key,
+		unsigned length,
+		const uint8_t *cleartext,
+		const uint8_t *ciphertext,
+		const uint8_t *iv);
+
+void
+test_cipher_stream(const struct nettle_cipher *cipher,
+		   unsigned key_length,
+		   const uint8_t *key,
+		   unsigned length,
+		   const uint8_t *cleartext,
+		   const uint8_t *ciphertext);
+
 void
 test_hash(const struct nettle_hash *hash,
 	  unsigned length,
@@ -72,6 +93,10 @@ test_armor(const struct nettle_armor *armor,
            const uint8_t *ascii);
 
 #if WITH_PUBLIC_KEY
+void
+test_rsa_set_key_1(struct rsa_public_key *pub,
+		   struct rsa_private_key *key);
+
 void
 test_rsa_md5(struct rsa_public_key *pub,
 	     struct rsa_private_key *key,
@@ -86,13 +111,24 @@ void
 test_rsa_key(struct rsa_public_key *pub,
 	     struct rsa_private_key *key);
 
+void
+test_dsa(const struct dsa_public_key *pub,
+	 const struct dsa_private_key *key);
+
+void
+test_dsa_key(struct dsa_public_key *pub,
+	     struct dsa_private_key *key);
+
 #endif /* WITH_PUBLIC_KEY */
 
 #define H2(d, s) decode_hex((d), (s))
 #define H(x) decode_hex_dup(x)
 #define HL(x) decode_hex_length(x), decode_hex_dup(x)
 
-#define LDATA(x) strlen(x), x
+/* LDATA needs to handle NUL characters. */
+#define LLENGTH(x) (sizeof(x) - 1)
+#define LDATA(x) (sizeof(x) - 1), x
+#define LDUP(x) strlen(x), strdup(x)
 
 #define MEMEQ(length, a, b) (!memcmp((a), (b), (length)))
 #define MEMEQH(length, a, b) \
